<?php

/**
 * @package   BP_Profile_Tabs
 * @author    Jacob Schweitzer <allambition@gmail.com>
 * @license   GPL-2.0+
 * @link      http://ijas.me
 * @copyright 2014 Jacob Schweitzer
 */

class BP_Profile_Tabs_Admin {

	/**
	 * Instance of this class.
	 *
	 * @since    1.5.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Slug of the plugin screen.
	 *
	 * @since    1.5.0
	 *
	 * @var      string
	 */
	protected $plugin_screen_hook_suffix = null;

	/**
	 * Initialize the plugin by loading admin scripts & styles and adding a
	 * settings page and menu.
	 *
	 * @since     1.0.0
	 */
	private function __construct() {

		/*
		 * Call $plugin_slug from public plugin class.
		 */
		$plugin = BP_Profile_Tabs::get_instance();
		$this->plugin_slug = $plugin->get_plugin_slug();
		$this->plugin_name = $plugin->get_plugin_name();
		$this->version = $plugin->get_plugin_version();
		$this->jquery_ui_version = $plugin->get_jquery_ui_version();

		// Add the options page and menu item.
		add_action( 'admin_menu', array( $this, 'add_plugin_admin_menu' ) );

		// Add an action link pointing to the options page.
		$plugin_basename = plugin_basename( plugin_dir_path( realpath( dirname( __FILE__ ) ) ) . $this->plugin_slug . '.php' );
		add_filter( 'plugin_action_links_' . $plugin_basename, array( $this, 'add_action_links' ) );

		/*
		 *  Custom Metabox and Fields for Wordpress
		 * 	https://github.com/WebDevStudios/Custom-Metaboxes-and-Fields-for-WordPress
		 */
		if ( !class_exists( 'cmb_Meta_Box' ) ) {
			add_action( 'init', array( $this, 'add_cmb_Meta_Box_class'), 9999 );
		}


		//Add the export settings method
		add_action( 'admin_init', array( $this, 'settings_export' ) );
		//Add the import settings method
		add_action( 'admin_init', array( $this, 'settings_import' ) );

		add_action( 'admin_init', array( $this, 'admin_register_bpt_script' ) );
		add_action( 'admin_head', array( $this, 'load_admin_scripts' ) );

	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	
	/**
	 * Register the  BuddyPress Profile Tabs administration menu into the WordPress Dashboard menu.
	 *
	 * @since    1.5.0
	 */
	public function add_plugin_admin_menu() {

		/*
		 * Add BuddyPress Profile Tabs settings page to the Settings menu.
		 */
		$this->plugin_screen_hook_suffix = add_options_page(
				__( 'BuddyPress Profile Tabs', $this->plugin_slug ), __( 'BP Profile Tabs', $this->plugin_slug ), 'manage_options', $this->plugin_slug, array( $this, 'display_plugin_admin_page' )
		);
	}

	/**
	 * Render the settings page for this plugin.
	 *
	 * @since    1.5.0
	 */
	public function display_plugin_admin_page() {
		include_once( 'views/admin.php' );
	}

	/**
	 * Add settings action link to the plugins page.
	 *
	 * @since    1.5.0
	 */
	public function add_action_links( $links ) {
		return array_merge(
				array(
			'settings' => '<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_slug ) . '">' . __( 'Settings' ) . '</a>',
				), $links
		);
	}


	function settings_export() {

		if ( empty( $_POST[ 'pn_action' ] ) || 'export_settings' != $_POST[ 'pn_action' ] ) {
			return;
		}
		
		if ( !wp_verify_nonce( $_POST[ 'pn_export_nonce' ], 'pn_export_nonce' ) ) {
			return;
		}
		
		if ( !current_user_can( 'manage_options' ) ) {
			return;
		}
		$settings[ 0 ] = get_option( 'bp_profile_tabs_option' );

		ignore_user_abort( true );

		nocache_headers();
		header( 'Content-Type: application/json; charset=utf-8' );
		header( 'Content-Disposition: attachment; filename=pn-settings-export-' . date( 'm-d-Y' ) . '.json' );
		header( "Expires: 0" );

		echo json_encode( $settings );
		exit;
	}

	/**
	 * Process a settings import from a json file
	 */
	function settings_import() {

		if ( empty( $_POST[ 'pn_action' ] ) || 'import_settings' != $_POST[ 'pn_action' ] ) {
			return;
		}
		
		if ( !wp_verify_nonce( $_POST[ 'pn_import_nonce' ], 'pn_import_nonce' ) ) {
			return;
		}
		
		if ( !current_user_can( 'manage_options' ) ) {
			return;
		}
		$extension = end( explode( '.', $_FILES[ 'import_file' ][ 'name' ] ) );

		if ( $extension != 'json' ) {
			wp_die( __( 'Please upload a valid .json file', $this->plugin_slug ) );
		}

		$import_file = $_FILES[ 'import_file' ][ 'tmp_name' ];

		if ( empty( $import_file ) ) {
			wp_die( __( 'Please upload a file to import', $this->plugin_slug ) );
		}

		// Retrieve the settings from the file and convert the json object to an array.
		$settings = ( array ) json_decode( file_get_contents( $import_file ) );

		update_option( 'bp_profile_tabs_option', get_object_vars( $settings[ 0 ] ) );

		wp_safe_redirect( admin_url( 'options-general.php?page=' . $this->plugin_slug ) );
		exit;
	}
	public function add_cmb_Meta_Box_class() {
		require_once( plugin_dir_path( __FILE__ ) . 'includes/CMBF/init.php' );
	}
	public function load_admin_scripts(){
		if ( $_GET['page'] === 'bp-profile-tabs' ) {
			wp_enqueue_style( $this->plugin_slug . '-jquery-ui-style' );
			wp_enqueue_script( $this->plugin_slug . '-script' );
		}
	}
	public function admin_register_bpt_script() {
		wp_register_script( $this->plugin_slug . '-script', plugins_url( 'assets/js/admin.js', __FILE__ ), array( 'jquery', 'jquery-ui-tabs' ), $this->version );
		$bpt_theme = isset( $_POST['bpt_theme'] ) ? $_POST['bpt_theme'] : '';
		$bpt_options = get_option("bp_profile_tabs_option");
		if ( empty( $bpt_theme ) ) {
			$bpt_theme = $bpt_options["bpt_theme"];
		}

		$protocol = is_ssl() ? 'https' : 'http';
		$jquery_ui_version = $this->jquery_ui_version;
		if ( $bpt_options['bpt_cdn'] == 'google' ) {
				$jquery_ui_css_url = $protocol . '://ajax.googleapis.com/ajax/libs/jqueryui/'.$jquery_ui_version.'/themes/'.$bpt_theme.'/jquery-ui.css';
									//http://ajax.googleapis.com/ajax/libs/jqueryui/1.11.2/themes/smoothness/jquery-ui.css
		}
		if ( $bpt_options['bpt_cdn'] == 'microsoft' ) {
			$jquery_ui_css_url = $protocol . '://ajax.aspnetcdn.com/ajax/jquery.ui/'.$jquery_ui_version.'/themes/'.$bpt_theme.'/jquery-ui.css';
										//http://ajax.aspnetcdn.com/ajax/jquery.ui/1.11.2/themes/blitzer/jquery-ui.css
										//http://ajax.aspnetcdn.com/ajax/jquery.ui/1.11.3/jquery-ui.min.js
		}
		if ( $bpt_options['bpt_cdn'] == 'jquery' ) {
			$jquery_ui_css_url = $protocol . '://code.jquery.com/ui/'.$jquery_ui_version.'/themes/'.$bpt_theme.'/jquery-ui.css';
		}
		wp_register_style( $this->plugin_slug . '-jquery-ui-style', $jquery_ui_css_url, array(), $this->version );
	}
	

}
